<?php


namespace Schaffen\WarehouseInventory\WarehouseInventory\Repositories;


use Freelabois\LaravelQuickstart\Extendables\Repository;
use Schaffen\Core\Product\Models\ProductVarietyPack;
use Schaffen\WarehouseInventory\WarehouseInventory\Models\SnapshotInventory;

class SnapshotInventoryRepository extends Repository
{
    protected $model = SnapshotInventory::class;

    protected $searchableFields = [
        ['field' => "sna_fk_loe_codigo"],
        ['field' => "sna_fk_pve_codigo"],
        ['field' => "sna_serial"],
    ];

    public function injectFiltersOnQuery()
    {
        $person = null;
        $not_zeroed = null;
        $quantity = null;

        extract($this->filters);

        $this->query->when($person, function ($query) use ($person) {
            return $query->whereHas('warehouse_inventory.person', function ($query) use ($person) {
                return $query->where('pes_codigo', $person);
            });
        });

        $this->query->when($not_zeroed, function ($query) use ($not_zeroed) {
            if (is_bool($not_zeroed) ? $not_zeroed : $not_zeroed == "true") {
                $query->where("sna_quantidade", '>', 0);
            }
            return $query;
        });

        $this->query->when($quantity, function ($query) use ($quantity) {
            $query->whereRaw("sna_quantidade - {$quantity} >= 0 ");
            return $query;
        });

        parent::injectFiltersOnQuery();
    }

    public function storeOrUpdate($values, int $id = null, array $relations = [])
    {
        foreach ($values['snapshot'] as $value) {
            $pve = ProductVarietyPack::where('pve_codigo', $value['pve_codigo'])->first();
            if($pve['pve_controla_estoque'] == 1) {
                $snap = SnapshotInventory::where('sna_fk_loe_codigo', $values['loe_codigo'])
                    ->where('sna_fk_pve_codigo', $value['pve_codigo'])
                    ->first();
                $qtd['sna_quantidade'] = $snap['sna_quantidade'] - $value['vei_quantidade'];
                $id = $snap['sna_codigo'];

                try {
                    parent::storeOrUpdate($qtd, $id, $relations);
                } catch (\Exception $e) {
                    return $e;
                }
            }
        }
        return true;
    }

}
